GFL_UtilFuncs = {}
GFL_ItemDictionary = {}

local CursorRelativeX = 0 -- Horizontal distance from cursor to TOPLEFT of MainFrame
local CursorRelativeY = 0 -- Vertical distance from cursor to TOPLEFT of MainFrame

local function AlignTooltip(self)
   GameTooltip:SetOwner(self, "ANCHOR_NONE")
   GameTooltip:SetPoint("TOPRIGHT", self, "BOTTOMRIGHT")
end

function GFL_UtilFuncs.RegisterEvents(self, callback, ...)
   for i = 1, select('#', ...) do
      self:RegisterEvent(select(i, ...))
   end
   self:SetScript("OnEvent", callback)
end

function GFL_UtilFuncs.ParseLink(link)
   if not link then
      return nil, nil
   end

   local id = strmatch(link, ".*Hitem:([^:]*)")
   local name = strmatch(link, ".*h%[([^%]]*)")

   return id, name
end

function GFL_UtilFuncs.GetItemLink(item)
   local _, link = GetItemInfo(item)
   local name = GFL_UtilFuncs.ParseLink(link)
   if name and not GFL_ItemDictionary[name] then
      GFL_ItemDictionary[name] = link
   end

   return link or GFL_ItemDictionary[item] or item
end

function GFL_UtilFuncs.SetFramePosition(frame, x, y, resetFunc)
   if not frame then
      return
   end

   if not x or not y then
      if resetFunc and type(resetFunc) == "function" then
         resetFunc(frame)
      end
   else
      frame:SetPoint("TOPLEFT", "UIParent", "BOTTOMLEFT", x, y)
   end
end

function GFL_UtilFuncs.GetFramePosition(frame)
   if not frame then
      return
   end

   --GFL_UtilFuncs.GetCursorRelativePosition(frame)
   local xpos, ypos = GetCursorPosition()
   local scale = frame:GetEffectiveScale()

   local x = (xpos / scale) - CursorRelativeX
   local y = (ypos / scale) - CursorRelativeY

   return x, y
end

function GFL_UtilFuncs.ShowToolTip(frame)
   if not frame then
      return
   end


   AlignTooltip(frame)
   --if contentFunc and type(contentFunc) == "function" then
      --contentFunc(self)
   --end
   GameTooltip:AddLine("Guild Currently Needs:")
   for i=1, #GFL_ItemsNeeded do
      item = GFL_UtilFuncs.GetItemLink(GFL_ItemsNeeded[i].Item)
      if item ~= GFL_ItemsNeeded[i].Item then
         GFL_ItemsNeeded[i].Item = item
      end
      GameTooltip:AddLine(item)
   end
   GameTooltip:Show()
end

function GFL_UtilFuncs.HideToolTip(frame)
   GameTooltip:Hide()
end

function GFL_UtilFuncs.ToggleFrame(frame)
   if not frame then
      return
   end

   PlaySound("igMainMenuQuit");
   if(frame:IsShown()) then
      frame:Hide()
   else
      frame:Show()
   end
end

function GFL_UtilFuncs.GetCursorRelativePosition(frame)
   if not frame then
      return
   end

   local xpos, ypos = GetCursorPosition()
   local xOffset = frame:GetLeft()
   local yOffset = frame:GetTop()
   local scale = frame:GetEffectiveScale()

   CursorRelativeX = (xpos / scale) - xOffset 
   CursorRelativeY = (ypos / scale) - yOffset
end
